@@ -161,6 +161,11 @@ class RootController(TGController):
     @expose()
     def save(self, *args, **kw):
         article = DBSession.query(Article).get(kw['uid'])
+
+        hooks = config['hooks'].get('smallpress.before_save_article', [])
+        for func in hooks:
+            func(article, kw)
+
         article.title = kw['title']
         article.description = kw['description']
         article.content = kw['content']
